@@ -1,11 +1,13 @@
 from kaldiliau.piansik_liansuann import freesyllable, piansik
 from kaldiliau.poo_lomaji_liansuann import tuitse, pooLomaji
-from kaldiliau.vad_liansuann import vad, vad_decoding
 from kaldiliau.poo_tuisiau_liansuann import pooLomaji_kah_sooji
+from kaldiliau.suansu_liansuann import suansu
+from kaldiliau.vad_liansuann import vad, vad_decoding
 
 
 __all__ = [
     'freesyllable', 'piansik',
     'tuitse', 'pooLomaji', 'pooLomaji_kah_sooji',
+    'suansu',
     'vad', 'vad_decoding',
 ]
